==> vue-components-1.5.43.tgz: package/lib/ui/checks/src/DescriptionCheckList.vue.rd.js <==
import { useVModel as m } from "@vueuse/core";
import { defineComponent as f, openBlock as s, createElementBlock as i, Fragment as n, createElementVNode as r, toDisplayString as a, createCommentVNode as c, normalizeClass as y, renderList as b, createBlock as g } from "vue";
import v from "./DescriptionCheck.vue.rd.js";
import { descriptionCheckListProps as C } from "./props.rd.js";
const w = { class: "text-left" }, V = {
  key: 0,
  class: "text-base font-bold text-gray-900 dark:text-white dark:text-white"
}, x = {
  key: 1,
  class: "text-md leading-5 mb-10 text-muted"
}, N = /* @__PURE__ */ f({
  __name: "DescriptionCheckList",
  props: C(),
  emits: ["update:checked"],
  setup(p, { emit: l }) {
    const h = m(p, "items");
    function k(e, o) {
      l("update:checked", { index: e, value: o }), h.value[e].checked = o;
    }
    return (e, o) => (s(), i(n, null, [
      r("div", w, [
        e.title ? (s(), i("label", V, a(e.title), 1)) : c("", !0),
        e.description ? (s(), i("p", x, a(e.description), 1)) : c("", !0)
      ]),
      r("fieldset", {
        class: y(["space-y-1 w-full", {
          "divide-y divide-gray-200 dark:divide-slate-600": e.position == "right" && e.showDivide,
          "space-y-8": e.position !== "right"
        }])
      }, [
        (s(!0), i(n, null, b(e.items, (t, d) => (s(), g(v, {
          key: (t == null ? void 0 : t.text) ?? d,
          text: t.text,
          position: e.position,
          type: e.type,
          disabled: e.disabled,
          description: t.description,
          checked: t.checked ?? !1,
          "onUpdate:checked": (u) => k(d, u)
        }, null, 8, ["text", "position", "type", "disabled", "description", "checked", "onUpdate:checked"]))), 128))
      ], 2)
    ], 64));
  }
});
export {
  N as default
};

==> vue-components-1.6.6.tgz: package/lib/ui/checks/src/DescriptionCheckList.vue.rd.js <==
import { defineComponent as m, openBlock as s, createElementBlock as i, Fragment as n, createElementVNode as r, toDisplayString as a, createCommentVNode as c, normalizeClass as f, renderList as y, createBlock as b } from "vue";
import { useVModel as g } from "@vueuse/core";
import v from "./DescriptionCheck.vue.rd.js";
import { descriptionCheckListProps as C } from "./props.rd.js";
const w = { class: "text-left" }, V = {
  key: 0,
  class: "text-base font-bold text-gray-900 dark:text-white dark:text-white"
}, x = {
  key: 1,
  class: "text-md leading-5 mb-10 text-muted"
}, N = /* @__PURE__ */ m({
  __name: "DescriptionCheckList",
  props: C(),
  emits: ["update:checked"],
  setup(p, { emit: l }) {
    const h = g(p, "items");
    function k(e, o) {
      l("update:checked", { index: e, value: o }), h.value[e].checked = o;
    }
    return (e, o) => (s(), i(n, null, [
      r("div", w, [
        e.title ? (s(), i("label", V, a(e.title), 1)) : c("", !0),
        e.description ? (s(), i("p", x, a(e.description), 1)) : c("", !0)
      ]),
      r("fieldset", {
        class: f(["space-y-1 w-full", {
          "divide-y divide-gray-200 dark:divide-slate-600": e.position == "right" && e.showDivide,
          "space-y-8": e.position !== "right"
        }])
      }, [
        (s(!0), i(n, null, y(e.items, (t, d) => (s(), b(v, {
          key: (t == null ? void 0 : t.text) ?? d,
          text: t.text,
          position: e.position,
          type: e.type,
          disabled: e.disabled,
          description: t.description,
          checked: t.checked ?? !1,
          "onUpdate:checked": (u) => k(d, u)
        }, null, 8, ["text", "position", "type", "disabled", "description", "checked", "onUpdate:checked"]))), 128))
      ], 2)
    ], 64));
  }
});
export {
  N as default
};
